% bLobatto Lobatto shape function.
%    P = bLobatto(z,n) computes Lobatto shape function of degree n>=1, 
%    which is the anti-derivative of the
%    Legendre polynomial P_n, evaluated for each element
%    of z.  n must be a scalar integer and z must contain real or 
%    complex values. 
%
% Examples: 
%   x = linspace(-1,1,100);
%   fx = bLobatto(x,5);
%   plot(x,fx);

function out = bLobatto(z,n)

z = z(:);

value = ones(size(z,1),n+2);
value(:,1) = (1-z)/2;
if(n>0)
  value(:,2) = (1+z)/2;
  value(:,3) = (z.^2-1)./2;
end

for k=1:n-1
    value(:,k+3) = ((2*k+1)*z.*value(:,k+2)-(k-1)*value(:,k+1))./(k+2);
end

out = value(:,3:end);