function [uh,xi,err] = fem_hat(N,a,b, f,u)
% Solution of the boundary value problem 
%    -u''(x) = f(x), x \in (-1,1)
%     u(-1) = u(1) = 0
% where we use hat-functions as basis functions


% overall N+2 nodes --> N inner nodes
xi = linspace(a,b,N+2);
h = xi(2:end) - xi(1:end-1);

% assemble stiffness matrix (spdiags)
% Stiffness Matrix only for inner nodes (N x N)
A = (N+1)/(b-a)*spdiags([-ones(N+2,1),2*ones(N+2,1), -ones(N+2,1)], [-1,0,1],N,N);

% assemble rhs (loop over inner nodes, use Matlab function quad)
b = zeros(N,1);
for i = 1:N
    phi1 = @(x) (x-  xi(i))./h(i);
    phi2 = @(x) (xi(i+2)-x)./h(i+1);
    b(i) = quad(@(x) phi1(x).*f(x),xi(i)  ,xi(i+1),1e-14) + ...
           quad(@(x) phi2(x).*f(x),xi(i+1),xi(i+2),1e-14);
end

%solve (only at inner nodes, because we know u(1) = u(N+2) = 0;
uh = zeros(N+2,1);
uh(2:N+1) = A\b;
  
% compute L^2 error --> loop over intervals and compute error for each
% interval
err = 0;
for i=1:N+1
  err = err+ h(i)* quad(@(x)( (1-x).*uh(i) + x.*uh(i+1) - u(xi(i) + h(i)*x) ).^2, 0,1,1e-14);
end
err = sqrt(err);
