function [uplot,xi,err] = fem_lobatto(N,a,b, f,u)
% Solution of the boundary value problem 
%    -u''(x) = f(x), x \in (-1,1)
%     u(-1) = u(1) = 0

% Legendre Ansatz phi_i(x) = int_{-1}^x P_i(t) dt, i = 1..N

% get Gauss points and weights
[wg xg] = gauss(63);
wg = [wg;wg]/2;
xg = 0.5*[xg-1; xg+1];

% evaluate basis at Gauss points
phi= bLobatto(xg,N);

% Assemble right hand side, loop over basis functions, use Gauss quadrature
rhs = zeros(N,1);
for i = 1:N
    rhs(i) = wg'*(f(xg).*phi(:,i));
end

% Assemble Matrix (spdiags)
A = spdiags(2./(2*(1:N)'+1), 0,N,N);

%solve
uh = A\rhs;

% evaluate uh and u at gauss points and compute error via Gauss quadrature
% (you need only one line!!!)
err = sqrt(wg'*(phi*uh-u(xg)).^2);

%display --> evaluate basis at plot points
xi = linspace(-1,1,300);
phi1 = bLobatto(xi,N);
uplot = (phi1*uh)';
