function [uplot,xi,err] = fem_sine(N,a,b, f,u)
% Solution of the boundary value problem 
%    -u''(x) = f(x), x \in (-1,1)
%     u(-1) = u(1) = 0
% with trigonometric basis phi_i(x) = sin(i*pi*x), i = 1 .. N

% get Gauss points and weights
[wg xg] = gauss(63);
wg = [wg;wg]/2;
xg = 0.5*[xg-1; xg+1];

% evaluate basis at Gauss points
phi = zeros(numel(xg),N);
for k = 1:N
  phi(:,k) = sin(k*pi*(xg+1)/2);
end

% Assemble right hand side, loop over basis functions, use Gauss quadrature
% either for loop or write in one line
rhs = zeros(N,1);
for i = 1:N
    rhs(i) = wg'*(f(xg).*phi(:,i));
end

% Assemble Matrix (spdiags)
A = spdiags(((1:N)'*pi/2).^2,0,N,N);

%solve
uh = A\rhs;

% evaluate uh and u at gauss points and compute error via Gauss quadrature
% (you need only one line!!!)
err = sqrt(wg'*(phi*uh-u(xg)).^2);

%display --> evaluate basis at plot points
xi = linspace(a,b,300);
phi1 = zeros(300,N);
for k = 1:N
  phi1(:,k) = sin(k*pi*(xi+1)/2);
end
uplot = (phi1*uh)';


